==> cxf-services-xkms-common-2.7.15-sources.jar: org/apache/cxf/xkms/model/xkms/UnverifiedKeyBindingType.java <==

package org.apache.cxf.xkms.model.xkms;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSeeAlso;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for UnverifiedKeyBindingType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="UnverifiedKeyBindingType">
 *   &lt;complexContent>
 *     &lt;extension base="{http://www.w3.org/2002/03/xkms#}KeyBindingAbstractType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.w3.org/2002/03/xkms#}ValidityInterval" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "UnverifiedKeyBindingType", propOrder = {
    "validityInterval"
})
@XmlSeeAlso({
    KeyBindingType.class
})
public class UnverifiedKeyBindingType
    extends KeyBindingAbstractType
{

    @XmlElement(name = "ValidityInterval")
    protected ValidityIntervalType validityInterval;

    /**
     * Gets the value of the validityInterval property.
     * 
     * @return
     *     possible object is
     *     {@link ValidityIntervalType }
     *     
     */
    public ValidityIntervalType getValidityInterval() {
        return validityInterval;
    }

    /**
     * Sets the value of the validityInterval property.
     * 
     * @param value
     *     allowed object is
     *     {@link ValidityIntervalType }
     *     
     */
    public void setValidityInterval(ValidityIntervalType value) {
        this.validityInterval = value;
    }

}

==> cxf-services-xkms-common-3.3.11-sources.jar: org/apache/cxf/xkms/model/xkms/UnverifiedKeyBindingType.java <==

package org.apache.cxf.xkms.model.xkms;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSeeAlso;
import javax.xml.bind.annotation.XmlType;


/**
 * &lt;p&gt;Java class for UnverifiedKeyBindingType complex type.
 * 
 * &lt;p&gt;The following schema fragment specifies the expected content contained within this class.
 * 
 * &lt;pre&gt;
 * &amp;lt;complexType name="UnverifiedKeyBindingType"&amp;gt;
 *   &amp;lt;complexContent&amp;gt;
 *     &amp;lt;extension base="{http://www.w3.org/2002/03/xkms#}KeyBindingAbstractType"&amp;gt;
 *       &amp;lt;sequence&amp;gt;
 *         &amp;lt;element ref="{http://www.w3.org/2002/03/xkms#}ValidityInterval" minOccurs="0"/&amp;gt;
 *       &amp;lt;/sequence&amp;gt;
 *     &amp;lt;/extension&amp;gt;
 *   &amp;lt;/complexContent&amp;gt;
 * &amp;lt;/complexType&amp;gt;
 * &lt;/pre&gt;
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "UnverifiedKeyBindingType", propOrder = {
    "validityInterval"
})
@XmlSeeAlso({
    KeyBindingType.class
})
public class UnverifiedKeyBindingType
    extends KeyBindingAbstractType
{

    @XmlElement(name = "ValidityInterval")
    protected ValidityIntervalType validityInterval;

    /**
     * Gets the value of the validityInterval property.
     * 
     * @return
     *     possible object is
     *     {@link ValidityIntervalType }
     *     
     */
    public ValidityIntervalType getValidityInterval() {
        return validityInterval;
    }

    /**
     * Sets the value of the validityInterval property.
     * 
     * @param value
     *     allowed object is
     *     {@link ValidityIntervalType }
     *     
     */
    public void setValidityInterval(ValidityIntervalType value) {
        this.validityInterval = value;
    }

}
